module Navigation exposing (Route(..), linkClicked, navTree, routeParser)

import Browser
import Browser.Navigation as Nav
import Html exposing (Html, a, details, li, summary, text, ul)
import Html.Attributes as Attr exposing (href)
import Url
import Url.Parser exposing ((</>), Parser, map, oneOf, s, top)


linkClicked : Browser.UrlRequest -> Nav.Key -> model -> ( model, Cmd msg )
linkClicked urlRequest key model =
    case urlRequest of
        Browser.Internal url ->
            ( model, Nav.pushUrl key (Url.toString url) )

        Browser.External href ->
            ( model, Nav.load href )


type Route
    = Home


routeParser : Parser (Route -> Route) Route
routeParser =
    oneOf
        [ map Home top
        --, map ShowTicket (s "tickets" </> Url.Parser.int)
        ]


navTree : Html msg
navTree =
    ul []
        [ li [] [ a [ href "/" ] [ text "Home" ] ]
        , li [] [ a [ href "/projects" ] [ text "Projects" ] ]
        , li []
            [ details [ Attr.attribute "open" "open" ]
                [ summary [] [ a [ href "/tickets" ] [ text "Tickets" ] ]
                , ul []
                    [ li [] [ a [ href "/tickets/new" ] [ text "New Ticket" ] ] ]
                ]
            ]
        ]
